@@ -4,7 +4,7 @@ build_time_vars = {'ABIFLAGS': '',
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ALIGNOF_LONG': 4,
- 'ALIGNOF_MAX_ALIGN_T': 8,
+ 'ALIGNOF_MAX_ALIGN_T': 4,
  'ALIGNOF_SIZE_T': 4,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
@@ -23,13 +23,14 @@ build_time_vars = {'ABIFLAGS': '',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'armv7--netbsdelf-eabihf',
+ 'BUILD_GNU_TYPE': 'shle--netbsdelf',
  'BUILD_SCRIPTS_DIR': 'build/scripts-3.12',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -I/usr/include '
-           '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include -O2 '
+ 'CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -Os -freorder-blocks '
+           '-I/usr/include -I/usr/pkg/include -Os -freorder-blocks '
+           '-I/usr/include -I/usr/pkg/include -Os -freorder-blocks '
            '-I/usr/include -I/usr/pkg/include',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
@@ -39,7 +40,7 @@ build_time_vars = {'ABIFLAGS': '',
  'COMPILEALL_OPTS': '-j0',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -I/usr/include -I/usr/pkg/include',
+ 'CONFIGURE_CFLAGS': '-Os -freorder-blocks -I/usr/include -I/usr/pkg/include',
  'CONFIGURE_CFLAGS_NODIST': '-std=gnu11 -Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
@@ -54,24 +55,23 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' '--with-system-expat' "
                 "'--without-ensurepip' '--without-pymalloc' "
                 "'--with-readline=readline' '--prefix=/usr/pkg' "
-                "'--build=armv7--netbsdelf-eabihf' "
-                "'--host=armv7--netbsdelf-eabihf' '--mandir=/usr/pkg/man' "
-                "'--enable-option-checking=yes' "
-                "'build_alias=armv7--netbsdelf-eabihf' "
-                "'host_alias=armv7--netbsdelf-eabihf' "
-                "'PKG_CONFIG=/mnt/earmv7hf/pkgsrc/lang/python312/work.earmv7hf/.tools/bin/pkg-config' "
+                "'--build=shle--netbsdelf' '--host=shle--netbsdelf' "
+                "'--mandir=/usr/pkg/man' '--enable-option-checking=yes' "
+                "'build_alias=shle--netbsdelf' 'host_alias=shle--netbsdelf' "
+                "'PKG_CONFIG=/tmp/pkgbuild/lang/python312/work/.tools/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/mnt/earmv7hf/pkgsrc/lang/python312/work.earmv7hf/.buildlink/lib/pkgconfig:/mnt/earmv7hf/pkgsrc/lang/python312/work.earmv7hf/.buildlink/share/pkgconfig' "
-                "'CC=gcc' 'CFLAGS=-O2 -I/usr/include -I/usr/pkg/include' "
-                "'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib "
-                "-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' "
-                "'LIBS=-lcrypt' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include'",
+                "'PKG_CONFIG_LIBDIR=/tmp/pkgbuild/lang/python312/work/.buildlink/lib/pkgconfig:/tmp/pkgbuild/lang/python312/work/.buildlink/share/pkgconfig' "
+                "'CC=gcc' 'CFLAGS=-Os -freorder-blocks -I/usr/include "
+                "-I/usr/pkg/include' 'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib "
+                '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
+                "-Wl,-R/usr/X11R7/lib' 'LIBS=-lcrypt' 'CPPFLAGS=-I/usr/include "
+                "-I/usr/pkg/include'",
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/mnt/earmv7hf/pkgsrc/lang/python312/work.earmv7hf/Python-3.12.11/coverage.info',
+ 'COVERAGE_INFO': '/tmp/pkgbuild/lang/python312/work/Python-3.12.12/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/mnt/earmv7hf/pkgsrc/lang/python312/work.earmv7hf/Python-3.12.11/lcov-report',
+ 'COVERAGE_REPORT': '/tmp/pkgbuild/lang/python312/work/Python-3.12.12/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
@@ -618,16 +618,16 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_H': 0,
  'HAVE__GETPTY': 0,
  'HOSTRUNNER': '',
- 'HOST_GNU_TYPE': 'armv7--netbsdelf-eabihf',
+ 'HOST_GNU_TYPE': 'shle--netbsdelf',
  'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
                    '/usr/pkg/include/python3.12 /usr/pkg/include/python3.12',
  'INCLUDEDIR': '/usr/pkg/include',
  'INCLUDEPY': '/usr/pkg/include/python3.12',
- 'INSTALL': '/usr/bin/install -c -o root -g wheel',
- 'INSTALL_DATA': '/usr/bin/install -c -o root -g wheel -m 644',
- 'INSTALL_PROGRAM': '/usr/bin/install -c -s -o root -g wheel -m 755',
- 'INSTALL_SCRIPT': '/usr/bin/install -c -o root -g wheel -m 755',
- 'INSTALL_SHARED': '/usr/bin/install -c -o root -g wheel -m 755',
+ 'INSTALL': '/usr/bin/install -c -o pbulk -g users',
+ 'INSTALL_DATA': '/usr/bin/install -c -o pbulk -g users -m 644',
+ 'INSTALL_PROGRAM': '/usr/bin/install -c -s -o pbulk -g users -m 755',
+ 'INSTALL_SCRIPT': '/usr/bin/install -c -o pbulk -g users -m 755',
+ 'INSTALL_SHARED': '/usr/bin/install -c -o pbulk -g users -m 755',
  'INSTSONAME': 'libpython3.12.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
@@ -651,9 +651,10 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDEST': '/usr/pkg/lib/python3.12',
  'LIBDIR': '/usr/pkg/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                    '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
-                    '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+ 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -Os '
+                    '-freorder-blocks -I/usr/include -I/usr/pkg/include -Os '
+                    '-freorder-blocks -I/usr/include -I/usr/pkg/include -Os '
+                    '-freorder-blocks -I/usr/include -I/usr/pkg/include '
                     '-std=gnu11 -Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration '
@@ -663,9 +664,10 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
  'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
-                   '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                   '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
-                   '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+                   '-fno-strict-overflow -Wsign-compare -DNDEBUG -Os '
+                   '-freorder-blocks -I/usr/include -I/usr/pkg/include -Os '
+                   '-freorder-blocks -I/usr/include -I/usr/pkg/include -Os '
+                   '-freorder-blocks -I/usr/include -I/usr/pkg/include '
                    '-std=gnu11 -Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
@@ -679,9 +681,10 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1 '
-                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                    '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
-                    '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -Os '
+                    '-freorder-blocks -I/usr/include -I/usr/pkg/include -Os '
+                    '-freorder-blocks -I/usr/include -I/usr/pkg/include -Os '
+                    '-freorder-blocks -I/usr/include -I/usr/pkg/include '
                     '-std=gnu11 -Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration '
@@ -1012,7 +1015,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPT': '-DNDEBUG -O2 -I/usr/include -I/usr/pkg/include',
+ 'OPT': '-DNDEBUG -Os -freorder-blocks -I/usr/include -I/usr/pkg/include',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
  'PACKAGE_STRING': 0,
@@ -1047,11 +1050,13 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                             '-I/usr/include -I/usr/pkg/include -O2 '
-                             '-I/usr/include -I/usr/pkg/include -O2 '
-                             '-I/usr/include -I/usr/pkg/include -std=gnu11 '
-                             '-Wextra -Wno-unused-parameter '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -Os '
+                             '-freorder-blocks -I/usr/include '
+                             '-I/usr/pkg/include -Os -freorder-blocks '
+                             '-I/usr/include -I/usr/pkg/include -Os '
+                             '-freorder-blocks -I/usr/include '
+                             '-I/usr/pkg/include -std=gnu11 -Wextra '
+                             '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
@@ -1059,17 +1064,19 @@ build_time_vars = {'ABIFLAGS': '',
                              '-I./Include -I/usr/include -I/usr/pkg/include '
                              '-I/usr/include -I/usr/pkg/include -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -I/usr/include '
-              '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include -O2 '
-              '-I/usr/include -I/usr/pkg/include',
+ 'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -Os '
+              '-freorder-blocks -I/usr/include -I/usr/pkg/include -Os '
+              '-freorder-blocks -I/usr/include -I/usr/pkg/include -Os '
+              '-freorder-blocks -I/usr/include -I/usr/pkg/include',
  'PY_CFLAGS_NODIST': '-std=gnu11 -Wextra -Wno-unused-parameter '
                      '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                   '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
-                   '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+ 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -Os '
+                   '-freorder-blocks -I/usr/include -I/usr/pkg/include -Os '
+                   '-freorder-blocks -I/usr/include -I/usr/pkg/include -Os '
+                   '-freorder-blocks -I/usr/include -I/usr/pkg/include '
                    '-std=gnu11 -Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
@@ -1097,10 +1104,11 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                        '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
-                        '-I/usr/pkg/include -O2 -I/usr/include '
-                        '-I/usr/pkg/include -std=gnu11 -Wextra '
+ 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -Os '
+                        '-freorder-blocks -I/usr/include -I/usr/pkg/include '
+                        '-Os -freorder-blocks -I/usr/include '
+                        '-I/usr/pkg/include -Os -freorder-blocks '
+                        '-I/usr/include -I/usr/pkg/include -std=gnu11 -Wextra '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
@@ -1118,7 +1126,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python312/work.earmv7hf/Python-3.12.11',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work/Python-3.12.12',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1196,10 +1204,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python312/work.earmv7hf/Python-3.12.11 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work/Python-3.12.12 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/mnt/earmv7hf/pkgsrc/lang/python312/work.earmv7hf/Python-3.12.11 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work/Python-3.12.12 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1229,8 +1237,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/mnt/earmv7hf/pkgsrc/lang/python312/work.earmv7hf/Python-3.12.11',
- 'abs_srcdir': '/mnt/earmv7hf/pkgsrc/lang/python312/work.earmv7hf/Python-3.12.11',
+ 'abs_builddir': '/tmp/pkgbuild/lang/python312/work/Python-3.12.12',
+ 'abs_srcdir': '/tmp/pkgbuild/lang/python312/work/Python-3.12.12',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
