@@ -23,14 +23,15 @@ build_time_vars = {'ABIFLAGS': '',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'armv7--netbsdelf-eabihf',
+ 'BUILD_GNU_TYPE': 'armv6--netbsdelf-eabihf',
  'BUILD_SCRIPTS_DIR': 'build/scripts-3.12',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -I/usr/include '
-           '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include -O2 '
-           '-I/usr/include -I/usr/pkg/include',
+           '-I/usr/pkg/include -Dz_off_t=long -O2 -I/usr/include '
+           '-I/usr/pkg/include -Dz_off_t=long -O2 -I/usr/include '
+           '-I/usr/pkg/include -Dz_off_t=long',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -39,13 +40,13 @@ build_time_vars = {'ABIFLAGS': '',
  'COMPILEALL_OPTS': '-j0',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -I/usr/include -I/usr/pkg/include',
+ 'CONFIGURE_CFLAGS': '-O2 -I/usr/include -I/usr/pkg/include -Dz_off_t=long',
  'CONFIGURE_CFLAGS_NODIST': '-std=gnu11 -Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
- 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/pkg/include',
+ 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/pkg/include -Dz_off_t=long',
  'CONFIGURE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                       '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
                       '-Wl,-R/usr/X11R7/lib',
@@ -54,29 +55,30 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' '--with-system-expat' "
                 "'--without-ensurepip' '--without-pymalloc' "
                 "'--with-readline=readline' '--prefix=/usr/pkg' "
-                "'--build=armv7--netbsdelf-eabihf' "
-                "'--host=armv7--netbsdelf-eabihf' '--mandir=/usr/pkg/man' "
+                "'--build=armv6--netbsdelf-eabihf' "
+                "'--host=armv6--netbsdelf-eabihf' '--mandir=/usr/pkg/man' "
                 "'--enable-option-checking=yes' "
-                "'build_alias=armv7--netbsdelf-eabihf' "
-                "'host_alias=armv7--netbsdelf-eabihf' "
+                "'build_alias=armv6--netbsdelf-eabihf' "
+                "'host_alias=armv6--netbsdelf-eabihf' "
                 "'PKG_CONFIG=/pbulk/work/lang/python312/work/.tools/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=' "
                 "'PKG_CONFIG_LIBDIR=/pbulk/work/lang/python312/work/.buildlink/lib/pkgconfig:/pbulk/work/lang/python312/work/.buildlink/share/pkgconfig' "
-                "'CC=gcc' 'CFLAGS=-O2 -I/usr/include -I/usr/pkg/include' "
-                "'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib "
-                "-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' "
-                "'LIBS=-lcrypt' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include'",
+                "'CC=gcc' 'CFLAGS=-O2 -I/usr/include -I/usr/pkg/include "
+                "-Dz_off_t=long' 'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib "
+                '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
+                "-Wl,-R/usr/X11R7/lib' 'LIBS=-lcrypt' 'CPPFLAGS=-I/usr/include "
+                "-I/usr/pkg/include -Dz_off_t=long'",
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/pbulk/work/lang/python312/work/Python-3.12.11/coverage.info',
+ 'COVERAGE_INFO': '/pbulk/work/lang/python312/work/Python-3.12.12/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/pbulk/work/lang/python312/work/Python-3.12.11/lcov-report',
+ 'COVERAGE_REPORT': '/pbulk/work/lang/python312/work/Python-3.12.12/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
- 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include -I/usr/include '
-             '-I/usr/pkg/include',
+ 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include -Dz_off_t=long '
+             '-I/usr/include -I/usr/pkg/include -Dz_off_t=long',
  'CXX': 'c++ -pthread',
  'DEEPFREEZE_C': 'Python/deepfreeze/deepfreeze.c',
  'DEEPFREEZE_DEPS': './Tools/build/deepfreeze.py _bootstrap_python '
@@ -618,7 +620,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_H': 0,
  'HAVE__GETPTY': 0,
  'HOSTRUNNER': '',
- 'HOST_GNU_TYPE': 'armv7--netbsdelf-eabihf',
+ 'HOST_GNU_TYPE': 'armv6--netbsdelf-eabihf',
  'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
                    '/usr/pkg/include/python3.12 /usr/pkg/include/python3.12',
  'INCLUDEDIR': '/usr/pkg/include',
@@ -652,26 +654,29 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDIR': '/usr/pkg/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                    '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
-                    '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+                    '-I/usr/include -I/usr/pkg/include -Dz_off_t=long -O2 '
+                    '-I/usr/include -I/usr/pkg/include -Dz_off_t=long -O2 '
+                    '-I/usr/include -I/usr/pkg/include -Dz_off_t=long '
                     '-std=gnu11 -Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                    '-I/usr/include -I/usr/pkg/include -I/usr/include '
-                    '-I/usr/pkg/include -fPIC -fPIC',
+                    '-I/usr/include -I/usr/pkg/include -Dz_off_t=long '
+                    '-I/usr/include -I/usr/pkg/include -Dz_off_t=long -fPIC '
+                    '-fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
  'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                   '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
-                   '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+                   '-I/usr/include -I/usr/pkg/include -Dz_off_t=long -O2 '
+                   '-I/usr/include -I/usr/pkg/include -Dz_off_t=long -O2 '
+                   '-I/usr/include -I/usr/pkg/include -Dz_off_t=long '
                    '-std=gnu11 -Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -I/usr/include '
-                   '-I/usr/pkg/include -I/usr/include -I/usr/pkg/include -fPIC '
-                   '-fPIC',
+                   '-I/usr/pkg/include -Dz_off_t=long -I/usr/include '
+                   '-I/usr/pkg/include -Dz_off_t=long -fPIC -fPIC',
  'LIBHACL_HEADERS': '\\',
  'LIBHACL_SHA2_A': 'Modules/_hacl/libHacl_Hash_SHA2.a',
  'LIBHACL_SHA2_HEADERS': '\\',
@@ -680,14 +685,16 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1 '
                     '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                    '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
-                    '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+                    '-I/usr/include -I/usr/pkg/include -Dz_off_t=long -O2 '
+                    '-I/usr/include -I/usr/pkg/include -Dz_off_t=long -O2 '
+                    '-I/usr/include -I/usr/pkg/include -Dz_off_t=long '
                     '-std=gnu11 -Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                    '-I/usr/include -I/usr/pkg/include -I/usr/include '
-                    '-I/usr/pkg/include -fPIC -fPIC',
+                    '-I/usr/include -I/usr/pkg/include -Dz_off_t=long '
+                    '-I/usr/include -I/usr/pkg/include -Dz_off_t=long -fPIC '
+                    '-fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
  'LIBOBJDIR': 'Python/',
@@ -1012,7 +1019,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPT': '-DNDEBUG -O2 -I/usr/include -I/usr/pkg/include',
+ 'OPT': '-DNDEBUG -O2 -I/usr/include -I/usr/pkg/include -Dz_off_t=long',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
  'PACKAGE_STRING': 0,
@@ -1048,40 +1055,44 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                             '-I/usr/include -I/usr/pkg/include -O2 '
-                             '-I/usr/include -I/usr/pkg/include -O2 '
-                             '-I/usr/include -I/usr/pkg/include -std=gnu11 '
+                             '-I/usr/include -I/usr/pkg/include -Dz_off_t=long '
+                             '-O2 -I/usr/include -I/usr/pkg/include '
+                             '-Dz_off_t=long -O2 -I/usr/include '
+                             '-I/usr/pkg/include -Dz_off_t=long -std=gnu11 '
                              '-Wextra -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
                              '-I./Include -I/usr/include -I/usr/pkg/include '
-                             '-I/usr/include -I/usr/pkg/include -fPIC '
-                             '-DPy_BUILD_CORE_BUILTIN',
+                             '-Dz_off_t=long -I/usr/include -I/usr/pkg/include '
+                             '-Dz_off_t=long -fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -I/usr/include '
-              '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include -O2 '
-              '-I/usr/include -I/usr/pkg/include',
+              '-I/usr/pkg/include -Dz_off_t=long -O2 -I/usr/include '
+              '-I/usr/pkg/include -Dz_off_t=long -O2 -I/usr/include '
+              '-I/usr/pkg/include -Dz_off_t=long',
  'PY_CFLAGS_NODIST': '-std=gnu11 -Wextra -Wno-unused-parameter '
                      '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                   '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
-                   '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
+                   '-I/usr/include -I/usr/pkg/include -Dz_off_t=long -O2 '
+                   '-I/usr/include -I/usr/pkg/include -Dz_off_t=long -O2 '
+                   '-I/usr/include -I/usr/pkg/include -Dz_off_t=long '
                    '-std=gnu11 -Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -I/usr/include '
-                   '-I/usr/pkg/include -I/usr/include -I/usr/pkg/include -fPIC '
-                   '-DPy_BUILD_CORE',
+                   '-I/usr/pkg/include -Dz_off_t=long -I/usr/include '
+                   '-I/usr/pkg/include -Dz_off_t=long -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                     '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib '
                     '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                     '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include '
-                '-I/usr/include -I/usr/pkg/include',
+                '-Dz_off_t=long -I/usr/include -I/usr/pkg/include '
+                '-Dz_off_t=long',
  'PY_ENABLE_SHARED': 1,
  'PY_HAVE_PERF_TRAMPOLINE': 0,
  'PY_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
@@ -1098,15 +1109,16 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                        '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
-                        '-I/usr/pkg/include -O2 -I/usr/include '
-                        '-I/usr/pkg/include -std=gnu11 -Wextra '
-                        '-Wno-unused-parameter -Wno-missing-field-initializers '
-                        '-Wstrict-prototypes '
+                        '-I/usr/include -I/usr/pkg/include -Dz_off_t=long -O2 '
+                        '-I/usr/include -I/usr/pkg/include -Dz_off_t=long -O2 '
+                        '-I/usr/include -I/usr/pkg/include -Dz_off_t=long '
+                        '-std=gnu11 -Wextra -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers -Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -I/usr/include -I/usr/pkg/include '
-                        '-I/usr/include -I/usr/pkg/include -fPIC',
+                        '-Dz_off_t=long -I/usr/include -I/usr/pkg/include '
+                        '-Dz_off_t=long -fPIC',
  'PY_SUPPORT_TIER': 0,
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
@@ -1118,7 +1130,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/pbulk/work/lang/python312/work/Python-3.12.11',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/pbulk/work/lang/python312/work/Python-3.12.12',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1196,10 +1208,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/pbulk/work/lang/python312/work/Python-3.12.11 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/pbulk/work/lang/python312/work/Python-3.12.12 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/pbulk/work/lang/python312/work/Python-3.12.11 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/pbulk/work/lang/python312/work/Python-3.12.12 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1229,8 +1241,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/pbulk/work/lang/python312/work/Python-3.12.11',
- 'abs_srcdir': '/pbulk/work/lang/python312/work/Python-3.12.11',
+ 'abs_builddir': '/pbulk/work/lang/python312/work/Python-3.12.12',
+ 'abs_srcdir': '/pbulk/work/lang/python312/work/Python-3.12.12',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
